@@ -19,6 +19,7 @@
 #include "utils.h"
 
 #define MAX_FILENAME_LEN 500
+#define INVALID_PL_TEMP -280226 // Temp reported by hwmon when PL SysMon not available
 
 FILE *fp_out;
 
@@ -403,8 +404,8 @@ static void read_int_sysfs_entry(char* base_filename, char* filepath, int id, lo
 	fp = fopen(filename, "r");
 	if(fp == NULL)
 	{
-		fprintf(fp_out, " File open returned with error : %s\n", strerror(errno));
-		exit(0);
+		fprintf(fp_out, "Failed to open %s\n", filename);
+		return;
 	}
 
 	if(fscanf(fp,"%ld",val) != 1)
@@ -439,8 +440,8 @@ static void read_float_sysfs_entry(char* base_filename, char* filepath, int id,
 	fp = fopen(filename, "r");
 	if(fp == NULL)
 	{
-		fprintf(fp_out, " File open returned with error : %s\n", strerror(errno));
-		exit(0);
+		fprintf(fp_out, "Failed to open %s\n", filename);
+		return;
 	}
 
 	if(fscanf(fp,"%f",val) != 1)
@@ -464,7 +465,7 @@ static void read_float_sysfs_entry(char* base_filename, char* filepath, int id,
  * @note         None.
  *
  ******************************************************************************/
-static int read_char_sysfs_entry(char* base_filename, char* filepath, int id, char* value)
+static void read_char_sysfs_entry(char* base_filename, char* filepath, int id, char* value)
 {
 
 	FILE *fp;
@@ -478,8 +479,8 @@ static int read_char_sysfs_entry(char* base_filename, char* filepath, int id, ch
 
 	if(fp == NULL)
 	{
-		fprintf(fp_out, "Unable to open %s\n",filename);
-		exit(0);
+		fprintf(fp_out, "Failed to open %s\n", filename);
+		return;
 	}
 
 	if(fscanf(fp,"%s",value) != 1)
@@ -488,8 +489,6 @@ static int read_char_sysfs_entry(char* base_filename, char* filepath, int id, ch
 	}
 	fclose(fp);
 
-	return(0);
-
 }
 
 /*****************************************************************************/
@@ -542,7 +541,9 @@ int print_cpu_frequency(int verbose_flag)
 	for(; cpu_id < num_cpus_conf; cpu_id++)
 	{
 		get_cpu_frequency(cpu_id,&cpu_freq);
-		fprintf(fp_out, "CPU%d\t:    %f MHz\n",cpu_id,(cpu_freq)/1000);
+		if (cpu_freq != 0) {
+			fprintf(fp_out, "CPU%d\t:    %f MHz\n",cpu_id,(cpu_freq)/1000);
+		}
 	}
 	fprintf(fp_out, "\n");
 
@@ -1057,7 +1058,7 @@ int print_sysmon_power_info(int verbose_flag, int sample_interval, int sample_wi
 
 	if(hwmon_id == -1)
 	{
-		fprintf(fp_out, "no hwmon device found for ams under /sys/class/hwmon\n");
+		fprintf(fp_out, "no hwmon device found for ams under /sys/class/hwmon\n\n");
 		return(0);
 	}
 
@@ -1135,7 +1136,12 @@ int print_sysmon_power_info(int verbose_flag, int sample_interval, int sample_wi
 		fprintf(fp_out, "VTT PS GTR voltage    					:     %ld mV\t\t %ld mV\n\n",VTT_PS_GTR,VTT_PS_GTR_avg);
 
 		fprintf(fp_out, "PL Sysmon\n");
-		fprintf(fp_out, "PL temperature    					:     %ld C\t\t %ld C\n\n",(PL_TEMP)/1000,(PL_TEMP_avg)/1000);
+		if (PL_TEMP_avg == INVALID_PL_TEMP) {
+			fprintf(fp_out, "PL Sysmon not available\n\n");
+		}
+		else {
+			fprintf(fp_out, "PL temperature    					:     %ld C\t\t %ld C\n\n",(PL_TEMP)/1000,(PL_TEMP_avg)/1000);
+                }
 
 	}
 	else
@@ -1155,7 +1161,12 @@ int print_sysmon_power_info(int verbose_flag, int sample_interval, int sample_wi
 		fprintf(fp_out, "VTT PS GTR voltage    					:     %ld mV\n\n",VTT_PS_GTR);
 
 		fprintf(fp_out, "PL Sysmon\n");
-		fprintf(fp_out, "PL temperature    					:     %ld C\n\n",(PL_TEMP)/1000);
+		if (PL_TEMP == INVALID_PL_TEMP) {
+			fprintf(fp_out, "PL Sysmon not available\n\n");
+		}
+		else {
+			fprintf(fp_out, "PL temperature    					:     %ld C\n\n",(PL_TEMP)/1000);
+		}
 	}
 
 	return(0);
